/*******************************************************************************
* File Name: Base_Rotation_Hitec.c  
* Version 2.10
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks. 
*  The compare value output may be configured to be active when the present 
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Base_Rotation_Hitec.h"

uint8 Base_Rotation_Hitec_initVar = 0u;

/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the 
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  Base_Rotation_Hitec_initVar: Is modified when this function is called for the first 
*   time. Is used to ensure that initialization happens only once.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(Base_Rotation_Hitec_initVar == 0u)
    {
        Base_Rotation_Hitec_Init();
        Base_Rotation_Hitec_initVar = 1u;
    }
    Base_Rotation_Hitec_Enable();

}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  Base_Rotation_Hitec_Start().
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_Init(void) 
{
    #if (Base_Rotation_Hitec_UsingFixedFunction || Base_Rotation_Hitec_UseControl)
        uint8 ctrl;
    #endif
    
    #if(!Base_Rotation_Hitec_UsingFixedFunction) 
        #if(Base_Rotation_Hitec_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 Base_Rotation_Hitec_interruptState;
        #endif
    #endif
    
   #if (Base_Rotation_Hitec_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        Base_Rotation_Hitec_CONTROL |= Base_Rotation_Hitec_CFG0_MODE;
        #if (Base_Rotation_Hitec_DeadBand2_4)
            Base_Rotation_Hitec_CONTROL |= Base_Rotation_Hitec_CFG0_DB;
        #endif
                
        /* Set the default Compare Mode */
        #if(Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
                ctrl = Base_Rotation_Hitec_CONTROL2 & ~Base_Rotation_Hitec_CTRL_CMPMODE1_MASK;
                Base_Rotation_Hitec_CONTROL2 = ctrl | Base_Rotation_Hitec_DEFAULT_COMPARE1_MODE;
        #endif
        #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
                ctrl = Base_Rotation_Hitec_CONTROL3 & ~Base_Rotation_Hitec_CTRL_CMPMODE1_MASK;
                Base_Rotation_Hitec_CONTROL3 = ctrl | Base_Rotation_Hitec_DEFAULT_COMPARE1_MODE;
        #endif
        
         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        Base_Rotation_Hitec_RT1 &= ~Base_Rotation_Hitec_RT1_MASK;
        Base_Rotation_Hitec_RT1 |= Base_Rotation_Hitec_SYNC;     
                
        /*Enable DSI Sync all all inputs of the PWM*/
        Base_Rotation_Hitec_RT1 &= ~(Base_Rotation_Hitec_SYNCDSI_MASK);
        Base_Rotation_Hitec_RT1 |= Base_Rotation_Hitec_SYNCDSI_EN;
       
    #elif (Base_Rotation_Hitec_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = Base_Rotation_Hitec_CONTROL & ~Base_Rotation_Hitec_CTRL_CMPMODE2_MASK & ~Base_Rotation_Hitec_CTRL_CMPMODE1_MASK;
        Base_Rotation_Hitec_CONTROL = ctrl | Base_Rotation_Hitec_DEFAULT_COMPARE2_MODE | Base_Rotation_Hitec_DEFAULT_COMPARE1_MODE;
    #endif 
        
    #if (!Base_Rotation_Hitec_UsingFixedFunction)
        #if (Base_Rotation_Hitec_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            Base_Rotation_Hitec_AUX_CONTROLDP0 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
        #else /* (Base_Rotation_Hitec_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            Base_Rotation_Hitec_AUX_CONTROLDP0 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
            Base_Rotation_Hitec_AUX_CONTROLDP1 |= (Base_Rotation_Hitec_AUX_CTRL_FIFO0_CLR);
        #endif
    #endif
        
    Base_Rotation_Hitec_WritePeriod(Base_Rotation_Hitec_INIT_PERIOD_VALUE);
    Base_Rotation_Hitec_WriteCounter(Base_Rotation_Hitec_INIT_PERIOD_VALUE);
        
        #if (Base_Rotation_Hitec_UseOneCompareMode)
            Base_Rotation_Hitec_WriteCompare(Base_Rotation_Hitec_INIT_COMPARE_VALUE1);
        #else
            Base_Rotation_Hitec_WriteCompare1(Base_Rotation_Hitec_INIT_COMPARE_VALUE1);
            Base_Rotation_Hitec_WriteCompare2(Base_Rotation_Hitec_INIT_COMPARE_VALUE2);
        #endif
        
        #if (Base_Rotation_Hitec_KillModeMinTime)
            Base_Rotation_Hitec_WriteKillTime(Base_Rotation_Hitec_MinimumKillTime);
        #endif
        
        #if (Base_Rotation_Hitec_DeadBandUsed)
            Base_Rotation_Hitec_WriteDeadTime(Base_Rotation_Hitec_INIT_DEAD_TIME);
        #endif

    #if (Base_Rotation_Hitec_UseStatus || Base_Rotation_Hitec_UsingFixedFunction)
        Base_Rotation_Hitec_SetInterruptMode(Base_Rotation_Hitec_INIT_INTERRUPTS_MODE);
    #endif
        
    #if (Base_Rotation_Hitec_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        Base_Rotation_Hitec_GLOBAL_ENABLE |= Base_Rotation_Hitec_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        Base_Rotation_Hitec_CONTROL2 |= Base_Rotation_Hitec_CTRL2_IRQ_SEL;
    #else
        #if(Base_Rotation_Hitec_UseStatus)
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            Base_Rotation_Hitec_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            Base_Rotation_Hitec_STATUS_AUX_CTRL |= Base_Rotation_Hitec_STATUS_ACTL_INT_EN_MASK;
            
             /* Exit Critical Region*/
            CyExitCriticalSection(Base_Rotation_Hitec_interruptState);
            
            /* Clear the FIFO to enable the Base_Rotation_Hitec_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            Base_Rotation_Hitec_ClearFIFO();
        #endif
    #endif
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Enable
********************************************************************************
*
* Summary: 
*  Enables the PWM block operation
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Side Effects: 
*  This works only if software enable mode is chosen
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (Base_Rotation_Hitec_UsingFixedFunction)
        Base_Rotation_Hitec_GLOBAL_ENABLE |= Base_Rotation_Hitec_BLOCK_EN_MASK;
        Base_Rotation_Hitec_GLOBAL_STBY_ENABLE |= Base_Rotation_Hitec_BLOCK_STBY_EN_MASK;
    #endif 
    
    /* Enable the PWM from the control register  */
    #if (Base_Rotation_Hitec_UseControl || Base_Rotation_Hitec_UsingFixedFunction)
        Base_Rotation_Hitec_CONTROL |= Base_Rotation_Hitec_CTRL_ENABLE;
    #endif
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_Stop(void) 
{
    #if (Base_Rotation_Hitec_UseControl || Base_Rotation_Hitec_UsingFixedFunction)
        Base_Rotation_Hitec_CONTROL &= ~Base_Rotation_Hitec_CTRL_ENABLE;
    #endif
    
    /* Globally disable the Fixed Function Block chosen */
    #if (Base_Rotation_Hitec_UsingFixedFunction)
        Base_Rotation_Hitec_GLOBAL_ENABLE &= ~Base_Rotation_Hitec_BLOCK_EN_MASK;
        Base_Rotation_Hitec_GLOBAL_STBY_ENABLE &= ~Base_Rotation_Hitec_BLOCK_STBY_EN_MASK;
    #endif
}


#if (Base_Rotation_Hitec_UseOneCompareMode)
#if (Base_Rotation_Hitec_CompareMode1SW)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_SetCompareMode
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm output when in Dither mode,
*  Center Align Mode or One Output Mode.
*
* Parameters:
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return:
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_SetCompareMode(uint8 comparemode) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
            #if(Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
                        uint8 comparemodemasked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT);
                        Base_Rotation_Hitec_CONTROL2 &= ~Base_Rotation_Hitec_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
                        Base_Rotation_Hitec_CONTROL2 |= comparemodemasked;  
                #endif
                
            #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
                    uint8 comparemodemasked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT);
            Base_Rotation_Hitec_CONTROL3 &= ~Base_Rotation_Hitec_CTRL_CMPMODE1_MASK; /*Clear Existing Data */
            Base_Rotation_Hitec_CONTROL3 |= comparemodemasked;     
                #endif
                
    #elif (Base_Rotation_Hitec_UseControl)
        uint8 comparemode1masked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT) & Base_Rotation_Hitec_CTRL_CMPMODE1_MASK;
        uint8 comparemode2masked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT) & Base_Rotation_Hitec_CTRL_CMPMODE2_MASK;
        Base_Rotation_Hitec_CONTROL &= ~(Base_Rotation_Hitec_CTRL_CMPMODE1_MASK | Base_Rotation_Hitec_CTRL_CMPMODE2_MASK); /*Clear existing mode */
        Base_Rotation_Hitec_CONTROL |= (comparemode1masked | comparemode2masked);
        
    #else
        uint8 temp = comparemode;
    #endif
}
#endif /* Base_Rotation_Hitec_CompareMode1SW */

#else /* UseOneCompareMode */


#if (Base_Rotation_Hitec_CompareMode1SW)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_SetCompareMode1
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm1 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_SetCompareMode1(uint8 comparemode) 
{
    uint8 comparemodemasked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE1_SHIFT) & Base_Rotation_Hitec_CTRL_CMPMODE1_MASK;
    #if(Base_Rotation_Hitec_UsingFixedFunction)
            #if(Base_Rotation_Hitec_PSOC3_ES2 || Base_Rotation_Hitec_PSOC5_ES1)
                        Base_Rotation_Hitec_CONTROL2 &= Base_Rotation_Hitec_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Base_Rotation_Hitec_CONTROL2 |= comparemodemasked; 
            #endif
                
                #if(Base_Rotation_Hitec_PSOC3_ES3 || Base_Rotation_Hitec_PSOC5_ES2)
                    Base_Rotation_Hitec_CONTROL3 &= Base_Rotation_Hitec_CTRL_CMPMODE1_MASK; /*Clear existing mode */
                        Base_Rotation_Hitec_CONTROL3 |= comparemodemasked; 
            #endif
                
    #elif (Base_Rotation_Hitec_UseControl)
        Base_Rotation_Hitec_CONTROL &= Base_Rotation_Hitec_CTRL_CMPMODE1_MASK; /*Clear existing mode */
        Base_Rotation_Hitec_CONTROL |= comparemodemasked;
    #endif    
}
#endif /* Base_Rotation_Hitec_CompareMode1SW */


#if (Base_Rotation_Hitec_CompareMode2SW)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_SetCompareMode2
********************************************************************************
* 
* Summary:
*  This function writes the Compare Mode for the pwm or pwm2 output
*
* Parameters:  
*  comparemode:  The new compare mode for the PWM output. Use the compare types
*                defined in the H file as input arguments.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_SetCompareMode2(uint8 comparemode) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
        /* Do Nothing because there is no second Compare Mode Register in FF block*/ 
    #elif (Base_Rotation_Hitec_UseControl)
    uint8 comparemodemasked = (comparemode << Base_Rotation_Hitec_CTRL_CMPMODE2_SHIFT) & Base_Rotation_Hitec_CTRL_CMPMODE2_MASK;
    Base_Rotation_Hitec_CONTROL &= Base_Rotation_Hitec_CTRL_CMPMODE2_MASK; /*Clear existing mode */
    Base_Rotation_Hitec_CONTROL |= comparemodemasked;
    #endif    
}
#endif /*Base_Rotation_Hitec_CompareMode2SW */
#endif /* UseOneCompareMode */


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WriteCounter
********************************************************************************
* 
* Summary:
*  This function is used to change the counter value.
*
* Parameters:  
*  counter:  This value may be between 1 and (2^Resolution)-1.   
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WriteCounter(uint16 counter) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
        CY_SET_REG16(Base_Rotation_Hitec_COUNTER_LSB_PTR, (uint16)counter);
    #else
        CY_SET_REG16(Base_Rotation_Hitec_COUNTER_LSB_PTR, counter);
    #endif
}


#if (!Base_Rotation_Hitec_UsingFixedFunction)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_ReadCounter
********************************************************************************
* 
* Summary:
*  This function returns the current value of the counter.  It doesn't matter
*  if the counter is enabled or running.
*
* Parameters:  
*  void  
*
* Return: 
*  The current value of the counter.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint16 Base_Rotation_Hitec_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    CY_GET_REG8(Base_Rotation_Hitec_COUNTERCAP_LSB_PTR);
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    return (CY_GET_REG16(Base_Rotation_Hitec_CAPTURE_LSB_PTR));
}


#if (Base_Rotation_Hitec_UseStatus)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_ClearFIFO
********************************************************************************
* 
* Summary:
*  This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_ClearFIFO(void) 
{
    while(Base_Rotation_Hitec_ReadStatusRegister() & Base_Rotation_Hitec_STATUS_FIFONEMPTY)
        Base_Rotation_Hitec_ReadCapture();
}
#endif /* Base_Rotation_Hitec_UseStatus */
#endif /* !Base_Rotation_Hitec_UsingFixedFunction */


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WritePeriod
********************************************************************************
* 
* Summary:
*  This function is used to change the period of the counter.  The new period 
*  will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0 
*           will result in the counter remaining at zero.
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WritePeriod(uint16 period) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
        CY_SET_REG16(Base_Rotation_Hitec_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG16(Base_Rotation_Hitec_PERIOD_LSB_PTR, period);
    #endif
}


#if (Base_Rotation_Hitec_UseOneCompareMode)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WriteCompare
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value when the PWM is in Dither
*  mode. The compare output will reflect the new value on the next UDB clock. 
*  The compare output will be driven high when the present counter value is 
*  compared to the compare value based on the compare mode defined in 
*  Dither Mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Side Effects:
*  This function is only available if the PWM mode parameter is set to
*  Dither Mode, Center Aligned Mode or One Output Mode
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WriteCompare(uint16 compare) 
{
   CY_SET_REG16(Base_Rotation_Hitec_COMPARE1_LSB_PTR, compare);
   #if (Base_Rotation_Hitec_PWMMode == Base_Rotation_Hitec__B_PWM__DITHER)
        CY_SET_REG16(Base_Rotation_Hitec_COMPARE2_LSB_PTR, compare+1);
   #endif
}


#else


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WriteCompare1
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare1 value.  The compare output will 
*  reflect the new value on the next UDB clock.  The compare output will be 
*  driven high when the present counter value is less than or less than or 
*  equal to the compare register, depending on the mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WriteCompare1(uint16 compare) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
        CY_SET_REG16(Base_Rotation_Hitec_COMPARE1_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG16(Base_Rotation_Hitec_COMPARE1_LSB_PTR, compare);
    #endif
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WriteCompare2
********************************************************************************
* 
* Summary:
*  This funtion is used to change the compare value, for compare1 output.  
*  The compare output will reflect the new value on the next UDB clock.  
*  The compare output will be driven high when the present counter value is 
*  less than or less than or equal to the compare register, depending on the 
*  mode.
*
* Parameters:  
*  compare:  New compare value.  
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WriteCompare2(uint16 compare) 
{
    #if(Base_Rotation_Hitec_UsingFixedFunction)
        CY_SET_REG16(Base_Rotation_Hitec_COMPARE2_LSB_PTR, compare);
    #else
        CY_SET_REG16(Base_Rotation_Hitec_COMPARE2_LSB_PTR, compare);
    #endif
}
#endif /* UseOneCompareMode */


#if (Base_Rotation_Hitec_DeadBandUsed)
/*******************************************************************************
* Function Name: Base_Rotation_Hitec_WriteDeadTime
********************************************************************************
* 
* Summary:
*  This function writes the dead-band counts to the corresponding register
*
* Parameters:  
*  deadtime:  Number of counts for dead time 
*
* Return: 
*  void
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void Base_Rotation_Hitec_WriteDeadTime(uint8 deadtime) 
{
    /* If using the Dead Band 1-255 mode then just write the register */
    #if(!Base_Rotation_Hitec_DeadBand2_4)
        CY_SET_REG8(Base_Rotation_Hitec_DEADBAND_COUNT_PTR, deadtime);
    #else
        /* Otherwise the data has to be masked and offset */        
        /* Clear existing data */
        Base_Rotation_Hitec_DEADBAND_COUNT &= ~Base_Rotation_Hitec_DEADBAND_COUNT_MASK; 
            /* Set new dead time */
        Base_Rotation_Hitec_DEADBAND_COUNT |= (deadtime << Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT) & Base_Rotation_Hitec_DEADBAND_COUNT_MASK; 
    #endif
}


/*******************************************************************************
* Function Name: Base_Rotation_Hitec_ReadDeadTime
********************************************************************************
* 
* Summary:
*  This function reads the dead-band counts from the corresponding register
*
* Parameters:  
*  void
*
* Return: 
*  Dead Band Counts
*
* Reentrant:
*  Yes
*
*******************************************************************************/
uint8 Base_Rotation_Hitec_ReadDeadTime(void) 
{
    /* If using the Dead Band 1-255 mode then just read the register */
    #if(!Base_Rotation_Hitec_DeadBand2_4)
        return (CY_GET_REG8(Base_Rotation_Hitec_DEADBAND_COUNT_PTR));
    #else
        /* Otherwise the data has to be masked and offset */
        return ((Base_Rotation_Hitec_DEADBAND_COUNT & Base_Rotation_Hitec_DEADBAND_COUNT_MASK) >> Base_Rotation_Hitec_DEADBAND_COUNT_SHIFT);
    #endif
}
#endif /* DeadBandUsed */

