/* --------------------------------------------------------------------------

* -----------------------------------------------------------------------------
* Malvin Maduna Ma Rui Nkomo 
* Shandong University of Science and Technology 
* Department of Electrical and Information Engineering
* Project: RGB colour sensing SCARA Robotic Arm 
* 09 December 2011
*****************************************************************************
*  Project Name: Red_Filter  
*  Device Tested:  CY8C5588AXI
*  Software Version: PSoC Creator Beta 5
*  Complier tested: Keil(C51) and GCC
*  
*****************************************************************************

* Description:
* =============
* The project aims at using the Counter to measure the time interval between 2 events. This project explains how 
* the counter can be configured to perform the time measurement between 2 events. The rising edge on a 
* particular signal is considered as an event. Thus this project measures time between 2 rising edges.
*
* Operation of Project:
* =====================
*  The counter is used for the time measurement. The counter is configured as an "Up counter" and captures
* at the rising edge. The counter is also configured to reload at capture. Thus whenever a rising edge occurs,
* the counter captures the count and resets the counter. The captured count value helps to measure the time
* between 2 events. The counter also is configured for "Terminal count" interrupt and "Capture" interrupt.
* Whenever the ?Capture interrupt? occurs, the captured count is read and the time value is calculated. 
* Whenever the ?Terminal count interrupt? occurs, the number of times the counter has overflown before
* the next capture occurred is counted. This count value is used to measure the time between 2 capture edges.
* The calculated time interval is displayed on the LCD in uints of microsecond. 
* The project can measure from 1 microsecond. The upper limit for measurement is set by various factors 
* explained in the document
*
* Components used:
* ================
* Counter block:
* Resolution -> 16 bit
* Period -> 0xFFFF
* Count direction -> Up counter
* Reload on Capture --> True
* Reload on Reset --> True
* Interrupt --> Terminal count and Capture interrupt
* Digital Input pin: 
* Mapped to P3[0] - This is the input signal whose time interval is measured
* Character LCD
* Hardware connections:
* =====================
* Connect the output from function generator to pin P3[0]
* The Character LCD module should be connected to the DVK
********************************************************************************************/



/* 
* Description:
* =============
* The TCS230 is polled for different colour filters and the output is used to determine the 
* colour detected.
* Operation of Project:
*
* Components used:

********************************************************************************************/

#include <device.h>

/* Defines for TRUE and FALSE */
#ifndef TRUE
    #define TRUE 1
#endif
#ifndef FALSE
    #define FALSE 0
#endif

void Red_Filter(void);
void delay_ms(unsigned int n);
			
/*S2 and S3 states */
#define SELECTOR_ON  0x01
#define SELECTOR_OFF 0x00

 extern uint8 S2;  /* Initially set S2 to ON so that it is on clear mode */
 extern uint8 S3;  /* Initially set S3 to OFF so that is is on clear mode */


/* Variable to indicate the occurence of the Counter Interrupt. The Counter generates interrupt on the the
 * Terminal count and/Or the Capture event. The flag is set inside the Counter interrupt and cleared in the
 * main.c after processing */
extern uint8 ISR_flag = 0;

/* Variable to store the Counter Status register. This value is used to find which is the cause of
 * Interupt (either Terminal Count or Capture event). The variable is updated inside the Counter ISR */
extern uint8 counter_status = 0;

/* Define to store the Frequency of the Clock used for the Counter component.
 * The value defined is in Hz */
#define CLOCK_FREQ (float)3000000

/* Define to indicate the number of microseconds in 1 second. Used for scaling purpose */
#define NO_OF_USEC 1000000

 /* The time measured between 2 events is stored in this variable. This variable is again a float because
     * of the precision required */


float measuredTimeRed = 0;


void Red_Filter()
	
	{
			
	/*Select the red  colour filter*/
	S2_Write(SELECTOR_OFF);      /* Set pin S2 high to select red  colour*/
	S3_Write(SELECTOR_OFF);  	/* Set pin S3 high to select red colour*/
	
		
    /* Variable to store the Period count value configured for the Counter component */
    uint16 counter_periodCountRed = 0;
    
    /* Variable to store the number of time the timer has overflown */
    uint16 counter_overflowCountRed = 0;
    
    /* This variable stores the period of the counter based on the period count and clock frequency value
     * The variable stores the calculated period as float and in seconds */
    float counter_period_inSecondsRed = 0;
   
    /* Variable to store the count value that is captured at the instance of the rising edge of the
     * capture signal */
    uint16 capturedCountRed = 0;
    
    /* Variable stores the time derived from the captured count value */
    float capturedCountTimeRed = 0;
    
    /* Initialize the components */
    Counter_Start();
  
    ISR_Counter_Start();
    
     
    /* Read the counter period count set in the configuration */
    counter_periodCountRed = Counter_ReadPeriod();
    
    /* Add one to counter_periodCount to include the count to reach 0. When the counter is
     * configured for e.g. 255 counts it will actually execute for 256 cycles*/
    /* Calculate the counter period. The value is stored in seconds */
    counter_period_inSecondsRed = (float)((uint32)counter_periodCountRed + 1) / CLOCK_FREQ;
    
    /* Enable the Global Interrupt */
    CYGlobalIntEnable;  

		int x; 
		
		for (x=0; x<2; x++)
		
		{

        /* Check if the Counter Interrupt has occurred */
        if (ISR_flag == TRUE)
        {
            /* Check if the Counter interrupt is caused by Terminal Count. This can be checked in the 
             * status register of the Counter. The Counter status register is read and the value is stored
             * in counter_status.
             * The defines Counter_STATUS_OVERFLOW_INT_EN_MASK and Counter_STATUS_CAPTURE_INT_EN_MASK can be
             * seen in Counter.h file.
             * These defines indicate the type of interrupt*/
            if ((counter_status & Counter_STATUS_OVERFLOW_INT_EN_MASK) == Counter_STATUS_OVERFLOW_INT_EN_MASK)
            {
                /* This checks if the interrupt is due to Terminal Count */
                /* Increment the counter_overflowCount. This variable keeps track of the number of times the
                 * counter had overflown before the capture signal occurred. This count is used to calculate the
                 * time when the capture occurs */
                counter_overflowCountRed++;
            }
             /* Check if the Counter interrupt is caused by Capture Event */
            if ((counter_status & Counter_STATUS_CAPTURE_INT_EN_MASK) == Counter_STATUS_CAPTURE_INT_EN_MASK)
            {
                /* This checks if the interrupt is due to Capture event */
                /* Read the value captured by the Counter on the rising edge of the capture signal */
                capturedCountRed = Counter_ReadCapture();
                
                /* Convert the captured count value into Time in seconds
                 * Time = Captured count / Clock frequency of the counter */
                capturedCountTimeRed = (float)(capturedCountRed + 1)/ CLOCK_FREQ;
                
                /* The counter is configured for "Reset on Capture" so that it resets automatically
                 * and is ready for the next measurement */
                /* Calculate the total time between 2 events.
                 * The measured time = (Number of times Counter Overflowed * Period of the Counter) +
                 *                      The time measured using the capture count */
                measuredTimeRed = (counter_overflowCountRed * counter_period_inSecondsRed) + capturedCountTimeRed;
                
                /* Convert the measuredTime to microseconds */
                measuredTimeRed *= NO_OF_USEC;
                
                /* Reset the Overflow counter for the new measurement */
                counter_overflowCountRed = 0;
                
                /* Display the measured time on the display. The measuredTime is converted 
                 * to Integer for the display */
	
			
		    LCD_Char_1_Position(0,8);
            LCD_Char_1_PrintInt16(HI16((uint32)measuredTimeRed));
            LCD_Char_1_Position(0,12);
            LCD_Char_1_PrintInt16(LO16((uint32)measuredTimeRed));
         	
			delay_ms(1000);	

            }
            
            /* Clear the ISR_flag to indicate that the processing is done and the time has been measure */
            ISR_flag = FALSE;
            
        } /* End of "if" check for ISR_flag */
    }   

}

